@@ -36,7 +36,6 @@
 #include "theme.h"
 #include "window.h"
 #include <goffice/utils/go-rangefunc.h>
-#include <locale.h>
 #include <unistd.h>
 #include <libgen.h>
 #include <gtk/gtk.h>
@@ -45,6 +44,7 @@
 #include <glib/gi18n-lib.h>
 #include <openbabel/mol.h>
 #include <openbabel/obconversion.h>
+#include <clocale>
 #include <stack>
 
 using namespace OpenBabel;
@@ -126,6 +126,16 @@ gcpDocument::~gcpDocument ()
 	pango_attr_list_unref (m_PangoAttrList);
 	if (m_Theme)
 		m_Theme->RemoveClient (this);
+	if (m_App)
+		static_cast<gcpApplication*> (m_App)->SetActiveDocument (NULL);
+	while (!m_RedoList.empty ()) {
+		delete m_RedoList.front ();
+		m_RedoList.pop_front ();
+	}
+	while (!m_UndoList.empty ()) {
+		delete m_UndoList.front ();
+		m_UndoList.pop_front ();
+	}
 }
 
 GtkWidget* gcpDocument::GetWidget()
@@ -596,7 +606,7 @@ bool gcpDocument::Load (xmlNodePtr root)
 		xmlFree (tmp);
 	}
 
-	node = GetNodeByName (root, "title");
+	node = GetNodeByName (root, (char*) "title");
 	if (node)
 	{
 		tmp = (char*) xmlNodeGetContent (node);
@@ -607,7 +617,7 @@ bool gcpDocument::Load (xmlNodePtr root)
 	}
 	if (m_Window)
 		m_Window->SetTitle (GetTitle ());
-	node = GetNodeByName (root, "author");
+	node = GetNodeByName (root, (char*) "author");
 	if (node)
 	{
 		tmp = (char*) xmlGetProp (node, (xmlChar*) "name");
@@ -621,7 +631,7 @@ bool gcpDocument::Load (xmlNodePtr root)
 			xmlFree (tmp);
 		}
 	}
-	node = GetNodeByName (root, "comment");
+	node = GetNodeByName (root, (char*) "comment");
 	if (node)
 	{
 		tmp = (char*) xmlNodeGetContent (node);
@@ -631,7 +641,7 @@ bool gcpDocument::Load (xmlNodePtr root)
 		}
 	}
 
-	node = GetNodeByName (root, "theme");
+	node = GetNodeByName (root, (char*) "theme");
 	if (node) {
 		gcpTheme *pTheme = new gcpTheme (NULL), *pLocalTheme;
 		pTheme->Load (node);
@@ -914,32 +924,28 @@ void gcpDocument::OnProperties()
 	new gcpDocPropDlg(this);
 }
 
-void gcpDocument::SetTitle(const gchar* title)
+void gcpDocument::SetTitle (const gchar* title)
 {
-	if (m_title) g_free(m_title);
-	if (*title) m_title = g_strdup(title);
-	else m_title = NULL;
+	g_free (m_title);
+	m_title = (title && *title)? g_strdup (title): NULL;
 }
 
-void gcpDocument::SetAuthor(const gchar* author)
+void gcpDocument::SetAuthor (const gchar* author)
 {
-	if (m_author) g_free(m_author);
-	if (*author) m_author = g_strdup(author);
-	else m_author = NULL;
+	g_free (m_author);
+	m_author = (author && *author)? g_strdup (author): NULL;
 }
 
-void gcpDocument::SetMail(const gchar* mail)
+void gcpDocument::SetMail (const gchar* mail)
 {
-	if (m_mail) g_free(m_mail);
-	if (*mail) m_mail = g_strdup(mail);
-	else m_mail = NULL;
+	g_free (m_mail);
+	m_mail = (mail && *mail)? g_strdup (mail): NULL;
 }
 
-void gcpDocument::SetComment(const gchar* comment)
+void gcpDocument::SetComment (const gchar* comment)
 {
-	if (m_comment) g_free(m_comment);
-	if (*comment) m_comment = g_strdup(comment);
-	else m_comment = NULL;
+	g_free (m_comment);
+	m_comment = (comment && *comment)? g_strdup (comment): NULL;
 }
 	
 void gcpDocument::AddObject(Object* pObject)
@@ -1100,7 +1106,7 @@ void gcpDocument::LoadObjects(xmlNodePtr node)
 		child = child->next;
 	}
 	//Now, add bonds
-	child = GetNodeByName(node, "bond");
+	child = GetNodeByName (node, (char*) "bond");
 	while (child)
 	{
 		gcpBond* pBond = new gcpBond();
@@ -1108,7 +1114,7 @@ void gcpDocument::LoadObjects(xmlNodePtr node)
 		if (pBond->Load(child))
 			AddBond(pBond);
 		else delete pBond;
-		child = GetNextNodeByName(child->next, "bond");
+		child = GetNextNodeByName (child->next, (char*) "bond");
 	}
 }
 
@@ -1211,6 +1217,8 @@ void gcpDocument::SetTheme (gcpTheme *theme)
 	pango_attr_list_insert (m_PangoAttrList, pango_attr_weight_new (theme->GetFontWeight ()));
 	pango_attr_list_insert (m_PangoAttrList, pango_attr_stretch_new (theme->GetFontStretch ()));
 	pango_attr_list_insert (m_PangoAttrList, pango_attr_variant_new (theme->GetFontVariant ()));
+	if (m_pView)
+		m_pView->UpdateTheme ();
 }
 
 bool gcpDocument::OnSignal (SignalId Signal, Object *Child)
@@ -1291,6 +1299,10 @@ double gcpDocument::GetMedianBondLength ()
 		}
 	}
 	if (nb > 0)
+#ifdef HAVE_VECTOR_DATA
 		go_range_median_inter_nonconst (lengths.data (), nb, &result);
+#else
+		go_range_median_inter_nonconst (&(*lengths.begin ()), nb, &result);
+#endif
 	return result;
 }
