@@ -472,6 +472,8 @@ void gcpThemeManager::ParseDir (string &path, ThemeType type)
 	if (dir) {
 		path += "/";
 		while ((name = g_dir_read_name (dir))) {
+			if (name[strlen (name) - 1] == '~')
+				continue; // don't read backups
 			filename = path + name;
 			doc = xmlParseFile (filename.c_str ());
 			node = doc->children;
@@ -489,6 +491,8 @@ void gcpThemeManager::ParseDir (string &path, ThemeType type)
 					if (theme->m_ThemeType == DEFAULT_THEME_TYPE || theme->m_ThemeType == GLOBAL_THEME_TYPE)
 						name = _(name);
 					if (m_Themes.find (name) != m_Themes.end ()) {
+						delete theme;
+						continue;
 					}
 					theme->m_ThemeType = type;
 					m_Themes[name] = theme;
