@@ -45,7 +45,7 @@ static void help_cb (gcpTools *box)
 }
 
 gcpTools::gcpTools (Application *App):
-	Dialog (App, DATADIR"/gchempaint-unstable/ui/tools.glade", "tools", App),
+	Dialog (App, GLADEDIR"/tools.glade", "tools", App),
 	m_UIManager (NULL)
 {
 	if (!xml) {
@@ -165,3 +165,11 @@ void gcpTools::OnHelp ()
 {
 	m_App->OnHelp (m_Tool->GetHelpTag ());
 }
+
+void gcpTools::SetElement (int Z)
+{
+	GtkComboPeriodic *w = reinterpret_cast<GtkComboPeriodic*> (glade_xml_get_widget (xml, "mendeleiev"));
+	gtk_combo_periodic_set_element (w, Z);
+	OnElementChanged (Z);
+}
+ 
