@@ -28,8 +28,8 @@
 #include <lib/view.h>
 #include <lib/widgetdata.h>
 #include <glib/gi18n-lib.h>
-#include <errno.h>
-#include <math.h>
+#include <cerrno>
+#include <cmath>
 
 
 TypeId GroupType = NoType;
@@ -41,7 +41,7 @@ static void on_group_properties (gcpGroup* group)
 
 gcpGroup::gcpGroup (): Object(GroupType)
 {
-	SetId ("gr1");
+	SetId ((char*) "gr1");
 	m_Align = false;
 	m_Spaced = false;
 }
@@ -50,14 +50,17 @@ gcpGroup::~gcpGroup ()
 {
 }
 
-bool gcpGroup::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
+bool gcpGroup::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y)
 {
 	GtkActionGroup *group = gtk_action_group_new ("group");
 	GtkAction *action = gtk_action_new ("group_properties", _("Group properties..."), NULL, NULL);
 	g_signal_connect_swapped (action, "activate", G_CALLBACK (on_group_properties), this);
 	gtk_action_group_add_action (group, action);
+	g_object_unref (action);
 	gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menuitem action='group_properties'/></popup></ui>", -1, NULL);
 	gtk_ui_manager_insert_action_group (UIManager, group, 0);
+	g_object_unref (group);
+	GetParent ()->BuildContextualMenu (UIManager, object, x, y);
 	return true;
 }
 
@@ -279,25 +282,25 @@ xmlNodePtr gcpGroup::Save (xmlDocPtr xml)
 		char *align_type = NULL;
 		switch (m_AlignType) {
 		case GCP_ALIGN_NORMAL:
-			align_type = "normal";
+			align_type = (char*) "normal";
 			break;
 		case GCP_ALIGN_TOP:
-			align_type = "top";
+			align_type = (char*) "top";
 			break;
 		case GCP_ALIGN_MID_HEIGHT:
-			align_type = "mid-height";
+			align_type = (char*) "mid-height";
 			break;
 		case GCP_ALIGN_BOTTOM:
-			align_type = "bottom";
+			align_type = (char*) "bottom";
 			break;
 		case GCP_ALIGN_LEFT:
-			align_type = "left";
+			align_type = (char*) "left";
 			break;
 		case GCP_ALIGN_CENTER:
-			align_type = "center";
+			align_type = (char*) "center";
 			break;
 		case GCP_ALIGN_RIGHT:
-			align_type = "right";
+			align_type = (char*) "right";
 			break;
 		}
 		xmlNewProp (node, (const xmlChar*) "align", (const xmlChar*) align_type);
